<?php

declare(strict_types=1);


namespace App\Utils\Money;


class Money
{

    private string $amount;
    private Currency $currency;

    public function __construct(
        string $amount,
        Currency $currency
    )
    {
        $this->amount = $amount;
        $this->currency = $currency;
    }

    /**
     * @return Currency
     */
    public function getCurrency(): Currency
    {
        return $this->currency;
    }

    /**
     * @return string
     */
    public function getAmount(): string
    {
        return $this->amount;
    }

    public function compare(Money $money): int
    {
        if (!$this->currency->isEqual($money->getCurrency())) {
            throw new \InvalidArgumentException('Different currencies cannot be compared');
        }

        return bccomp($this->amount, $money->getAmount(), $this->currency->getPrecision());
    }

    public function add(Money $money): Money
    {
        if (!$this->currency->isEqual($money->getCurrency())) {
            throw new \InvalidArgumentException('Different currencies cannot added');
        }

        return new Money(bcadd($this->amount, $money->amount, $this->currency->getPrecision()), $this->currency);
    }

    public function sub(Money $money): Money
    {
        if (!$this->currency->isEqual($money->getCurrency())) {
            throw new \InvalidArgumentException('Different currencies cannot added');
        }

        return new Money(bcsub($this->amount, $money->amount, $this->currency->getPrecision()), $this->currency);
    }
}